@@ -66,6 +66,8 @@ void deleditordata(EditorData p){
 	fix_editor_up = FALSE;
     free(p->filename);
     free(p->title);
+    free(p->hmenu);
+    free(p->pmenu);
     free(p);
 }
 
@@ -503,6 +505,8 @@ static void editormenuact(control m)
 	enable(p->mfind);
 	enable(p->mreplace);
     }
+    helpmenuact(p->hmenu);
+    pkgmenuact(p->pmenu);
 }
 
 static void editorresize(editor c, rect r)
@@ -712,7 +716,9 @@ static editor neweditor()
     MCHECK(newmenuitem(G_("GUI preferences..."), 0, menuconfig));
 
     /* Packages menu should go here */
-    RguiPackageMenu();
+    p->pmenu = (PkgMenuItems) malloc(sizeof(struct structPkgMenuItems));
+    RguiPackageMenu(p->pmenu);
+
 #ifdef USE_MDI
     newmdimenu(); /* Create and fill the 'Window' menu */
 #endif
@@ -720,7 +726,8 @@ static editor neweditor()
     MCHECK(m = newmenu(G_("Help")));
     MCHECK(newmenuitem(G_("Editor"), 0, menueditorhelp));
     MCHECK(newmenuitem("-", 0, NULL));
-    RguiCommonHelp(m);
+    p->hmenu = (HelpMenuItems) malloc(sizeof(struct structHelpMenuItems));
+    RguiCommonHelp(m, p->hmenu);
 
     settextfont(t, editorfn);
     setresize(c, editorresize);
@@ -791,11 +798,12 @@ int Rgui_Edit(char *filename, char *title, int stealconsole)
 	editor_set_title(c, G_("Untitled"));
     }
     show(c);
+    
+    p = getdata(getdata(c));
+    p->stealconsole = stealconsole;
     if (stealconsole) {
-	p = getdata(getdata(c));
-	p->stealconsole = TRUE;
-	fix_editor_up = TRUE;
-	eventloop(c);
+    	fix_editor_up = TRUE;
+    	eventloop(c);
     }
     return 0;
 }
