@@ -39,6 +39,7 @@
 #include "rui.h"
 
 
+/* RAND_MAX is 0x7FFF on Windows */
 char * R_tmpnam(const char * prefix, const char * tempdir)
 {
     char tm[MAX_PATH], tmp1[MAX_PATH], *res;
@@ -51,7 +52,7 @@ char * R_tmpnam(const char * prefix, const char * tempdir)
     strcpy(tmp1, tempdir);
     for (n = 0; n < 100; n++) {
 	/* try a random number at the end */
-        sprintf(tm, "%s\\%s%d", tmp1, prefix, rand());
+        sprintf(tm, "%s\\%s%x%x", tmp1, prefix, rand(), rand());
         if ((h = FindFirstFile(tm, &fd)) == INVALID_HANDLE_VALUE) {
 	    done = 1;
 	    break;
@@ -966,13 +967,12 @@ int Rwin_rename(char *from, char *to)
     return res;
 }
 
+extern char * mkdtemp (char *template);
+
 void InitTempDir()
 {
-    char *tmp, tm[MAX_PATH], tmp1[MAX_PATH], *p;
-    unsigned int n;
-    int hasspace = 0, len, done = 0, res;
-    WIN32_FIND_DATA fd;
-    HANDLE h;
+    char *tmp, *tm, tmp1[MAX_PATH], tmp2[MAX_PATH+11], *p;
+    int hasspace = 0, len;
 
     tmp = getenv("TMP");
     if(access(tmp, W_OK) != 0) tmp = NULL;
@@ -986,28 +986,10 @@ void InitTempDir()
 	GetShortPathName(tmp, tmp1, MAX_PATH);
     else
 	strcpy(tmp1, tmp); /* length must be valid as access has been checked */
-    /* now try a random addition */
-    srand( (unsigned)time( NULL ) );
-    for (n = 0; n < 100; n++) {
-	/* try a random number at the end */
-        sprintf(tm, "%s\\%s%d", tmp1, "Rtmp", rand());
-        if ((h = FindFirstFile(tm, &fd)) == INVALID_HANDLE_VALUE) {
-	    done = 1;
-	    break;
-	}
-        FindClose(h);
-        tm[0] = '\0';
-    }
-    if(!done)
-	R_Suicide("cannot find unused tempdir name");
-    /* Now try to create it */
-    res = mkdir(tm);
-    if(res) {
-	char buff[2000];
-	sprintf(buff, "%s\nDoes %s exist and is it writeable?",
-		"Can't mkdir R_TempDir", tmp);
-	R_Suicide(buff);
-    }
+    sprintf(tmp2, "%s/RtmpXXXXXX", tmp1);
+    tm = mkdtemp(tmp2);
+    if(!tm) R_Suicide(_("cannot mkdir R_TempDir"));
+
     len = strlen(tm);
     p = (char *) malloc(len+1);
     if(!p) R_Suicide("Can't allocate R_TempDir");
