@@ -16,12 +16,6 @@ X11 <- function(display = "", width = 7, height = 7, pointsize = 12,
 
 x11 <- X11
 
-gnome <- function(display = "", width = 7, height = 7, pointsize = 12)
-    .Defunct(package="grDevices")
-
-## no Gnome <- .Alias(gnome)
-GNOME <- gnome
-
 ####################
 # X11 font database
 ####################
