@@ -1,5 +1,6 @@
 pie <-
     function (x, labels = names(x), edges = 200, radius = 0.8,
+              clockwise = FALSE, init.angle = if(clockwise) 90 else 0,
               density = NULL, angle = 45, col = NULL, border = NULL, lty = NULL,
               main = NULL, ...)
 {
@@ -9,6 +10,7 @@ pie <-
 	labels <- as.character(1:length(x))
     x <- c(0, cumsum(x)/sum(x))
     dx <- diff(x)
+    nx <- length(dx)
     plot.new()
     # NOTE: this needs to happen AFTER the plot.new so that
     # we enquire about the CURRENT plot region size, not the
@@ -18,7 +20,6 @@ pie <-
     if (pin[1] > pin[2]) xlim <- (pin[1]/pin[2]) * xlim
     else ylim <- (pin[2]/pin[1]) * ylim
     plot.window(xlim, ylim, "", asp = 1)
-    nx <- length(dx)
     if (is.null(col))
         col <- if(is.null(density))
             c("white", "lightblue", "mistyrose", "lightcyan", "lavender", "cornsilk")
@@ -28,20 +29,21 @@ pie <-
     lty <- rep(lty, length.out = nx)
     angle <- rep(angle, length.out = nx)
     density <- rep(density, length.out = nx)
+    twopi <- if(clockwise) -2*pi else 2*pi
+    t2xy <- function(t) {
+        t2p <- twopi*t + init.angle * pi/180
+        list(x = radius * cos(t2p), y = radius * sin(t2p))
+    }
     for (i in 1:nx) {
 	n <- max(2, floor(edges * dx[i]))
-	t2p <- 2*pi * seq(x[i], x[i + 1], length = n)
-	xc <- c(cos(t2p), 0) * radius
-	yc <- c(sin(t2p), 0) * radius
-	polygon(xc, yc, density = density[i], angle = angle[i],
+	P <- t2xy(seq(x[i], x[i + 1], length = n))
+	polygon(c(P$x, 0), c(P$y, 0), density = density[i], angle = angle[i],
                 border = border[i], col = col[i], lty = lty[i])
-	t2p <- 2*pi * mean(x[i + 0:1])
-	xc <- cos(t2p) * radius
-	yc <- sin(t2p) * radius
+	P <- t2xy(mean(x[i + 0:1]))
         if(!is.na(lab <- labels[i]) && lab != "") {
-            lines(c(1, 1.05)*xc, c(1, 1.05)*yc)
-            text(1.1*xc, 1.1*yc, lab, xpd = TRUE, adj = ifelse(xc < 0, 1, 0),
-                 ...)
+            lines(c(1, 1.05)*P$x, c(1, 1.05)*P$y)
+            text(1.1*P$x, 1.1*P$y, lab, xpd = TRUE,
+                 adj = ifelse(P$x < 0, 1, 0), ...)
         }
     }
     title(main = main, ...)
