@@ -8,12 +8,15 @@ prcomp.default <-
     cen <- attr(x, "scaled:center")
     sc <- attr(x, "scaled:scale")
     s <- svd(x, nu = 0)
-    if (!is.null(tol)) {
-        rank <- sum(s$d > (s$d[1]*tol))
-        if (rank < ncol(x))
-            s$v <- s$v[, 1:rank, drop = FALSE]
-    }
     s$d <- s$d / sqrt(max(1, nrow(x) - 1))
+    if (!is.null(tol)) {
+        ## we get rank at least one even for a 0 matrix.
+        rank <- sum(s$d > (s$d[1]*tol))
+        if (rank < ncol(x)) {
+            s$v <- s$v[, 1:rank, drop = FALSE]
+            s$d <- s$d[1:rank]
+        }
+    }
     dimnames(s$v) <-
         list(colnames(x), paste("PC", seq(len = ncol(s$v)), sep = ""))
     r <- list(sdev = s$d, rotation = s$v,
@@ -96,5 +99,18 @@ predict.prcomp <- function(object, newdata, ...)
         if(!is.null(object$x)) return(object$x)
         else stop("no scores are available: refit with 'retx=TRUE'")
     }
+    if(length(dim(newdata)) != 2)
+        stop("'newdata' must be a matrix or data frame")
+    p <- NCOL(object$rotation)
+    nm <- rownames(object$rotation)
+    if(!is.null(nm)) {
+        if(!all(nm %in% colnames(newdata)))
+            stop("'newdata' does not have named columns matching one or more of the original columns")
+        newdata <- newdata[, nm, drop = FALSE]
+    } else {
+        if(NCOL(newdata) != p)
+            stop("'newdata' does not have the correct number of columns")
+    }
+    ## next line does as.matrix
     scale(newdata, object$center, object$scale) %*% object$rotation
 }
