@@ -10,14 +10,13 @@ reshape <-
         if (drop)
             nn <- do.call("rbind",strsplit(nms,re))
         else
-            nn <- cbind(substr(nms,1,regexpr(re,nms)),
-                        substr(nms,regexpr(re,nms)+1,nchar(nms)))
+            nn <- cbind(substr(nms, 1, regexpr(re,nms)),
+                        substr(nms, regexpr(re,nms)+1, 10000))
         v.names <- tapply(nms,nn[,1],c)
         varying <- unique(nn[,1])
-        times <- sort(unique(nn[,2]))
+        times <- unique(nn[,2])
         attr(v.names,"v.names") <- varying
-        tt <- as.numeric(times)
-        if (is.factor(tt)) tt <- times
+        tt <- tryCatch({as.numeric(times)}, warning=function(w) times)
         attr(v.names,"times") <- tt
         v.names
     }
@@ -70,7 +69,11 @@ reshape <-
 
         rval <- d
 
-        if (length(times) == 1) return(rval)
+        if (length(times) == 1) {
+            if (drop.idvar)
+                rval[,idvar]<-NULL
+            return(rval)
+        }
         if (is.null(new.row.names))
             row.names(rval) <- paste(d[,idvar],times[1],sep = ".")
         else
@@ -90,8 +93,8 @@ reshape <-
 
         ## if we created a temporary id variable, drop it
         if (drop.idvar)
-            rval[,idvar]<-NULL 
-        
+            rval[,idvar]<-NULL
+
         attr(rval,"reshapeLong") <- undoInfo
         return(rval)
     } ## re..Long()
@@ -117,14 +120,14 @@ reshape <-
             idvar<-tempidname
             drop.idvar<-TRUE
         } else drop.idvar<-FALSE
-        
+
         ## times <- sort(unique(data[,timevar]))
         ## varying and times must have the same order
         times <- unique(data[,timevar])
         if (any(is.na(times)))
-            warning("There are records with missing times, which will be dropped.")
+            warning("there are records with missing times, which will be dropped.")
         undoInfo$times<-times
-        
+
         if (is.null(v.names))
             v.names <- names(data)[!(names(data) %in% c(timevar,idvar,orig.idvar))]
 
@@ -135,7 +138,7 @@ reshape <-
 
         undoInfo$varying<-varying
 
-        
+
         CHECK <- TRUE
         if (CHECK) {
             keep <- !(names(data) %in% c(timevar,v.names,idvar,orig.idvar))
@@ -147,9 +150,8 @@ reshape <-
                                   function(a) all(tapply(a, tmp,
                                                          function(b) length(unique(b)) == 1))))
                 if (!all(really.constant))
-                    warning("Some constant variables (",
-                            paste(names(rval)[!really.constant],collapse = ","),
-                            ") are really varying")
+                    warning(gettextf("some constant variables (%s) are really varying",
+                                     paste(names(rval)[!really.constant],collapse = ",")), domain = NA)
             }
         }
 
@@ -190,7 +192,7 @@ reshape <-
        {
            if (missing(timevar) && missing(idvar)) {
                back <- attr(data,"reshapeLong")
-               if (is.null(back)) stop("No time or id specified")
+               if (is.null(back)) stop("no 'time' or 'id' specified")
                reshapeWide(data, idvar = back$idvar, timevar = back$timevar,
                            varying = back$varying, v.names = back$v.names,
                            new.row.names = new.row.names)
@@ -205,7 +207,7 @@ reshape <-
        {
            if (missing(timevar) && missing(idvar) && missing(v.names) && missing(varying)) {
                back <- attr(data,"reshapeWide")
-               if (is.null(back)) stop("No time or id specified")
+               if (is.null(back)) stop("no 'time' or 'id' specified")
                reshapeLong(data, idvar = back$idvar, timevar = back$timevar,
                            varying = back$varying, v.names = back$v.names,
                            times = back$times)
