@@ -27,5 +27,10 @@
 #define _(String) (String)
 #endif
 
+void band_ucv_bin(int *, int *, double *, int *, double *, double *);
+void band_bcv_bin(int *, int *, double *, int *, double *, double *);
+void band_phi4_bin(int *, int *, double *, int *, double *, double *);
+void band_phi6_bin(int *, int *, double *, int *, double *, double *);
+void band_den_bin(int *, int *, double *, int *, double *, double *);
 
 #endif
