@@ -242,7 +242,7 @@ wsbrowser <- function(IDS, IsRoot, IsContainer, ItemsPerContainer,
 	   )
     if(substr(url, 1,1) != "/")
 	url <- paste("/", url, sep = "")
-    url <- paste("file://", url, sep = "")
+    url <- paste("file://", URLencode(url), sep = "")
 
     browseURL(url = url, browser = browser)
     cat(main, "environment is shown in browser",
